@@ -22,10 +22,9 @@ import osprofiler.initializer
 from glance.api import common
 import glance.async_
 from glance.common import config
-from glance.common import exception
 from glance.common import store_utils
 from glance import housekeeping
-from glance.i18n import _
+from glance.i18n import _, _LW
 from glance import notifier
 
 CONF = cfg.CONF
@@ -80,16 +79,6 @@ def _setup_os_profiler():
                                               host=CONF.bind_host)
 
 
-def _validate_policy_enforcement_configuration():
-    if CONF.enforce_secure_rbac != CONF.oslo_policy.enforce_new_defaults:
-        fail_message = (
-            "[DEFAULT] enforce_secure_rbac does not match "
-            "[oslo_policy] enforce_new_defaults. Please set both to "
-            "True to enable secure RBAC personas. Otherwise, make sure "
-            "both are False.")
-        raise exception.ServerError(fail_message)
-
-
 def drain_workers():
     # NOTE(danms): If there are any other named pools that we need to
     # drain before exit, they should be in this list.
@@ -152,8 +141,16 @@ def init_app():
         glance_store.create_stores(CONF)
         glance_store.verify_default_store()
 
+    # NOTE(danms): This may raise GlanceException if the staging store is
+    # not configured properly, which will bubble up to the WSGI server,
+    # aborting application load as desired.
+    staging = housekeeping.staging_store_path()
+    if not os.path.exists(staging) and CONF.enabled_import_methods:
+        LOG.warning(_LW('Import methods are enabled but staging directory '
+                        '%(path)s does not exist; Imports will fail!'),
+                    {'path': staging})
+
     run_staging_cleanup()
 
     _setup_os_profiler()
-    _validate_policy_enforcement_configuration()
     return config.load_paste_app('glance-api')
